@@ -1,15 +1,19 @@
-__version__ = "0.6.0"
+__version__ = "0.8.0"
 
+from .collection import Collection
 from .container import Container
 from .hashable import Hashable
 from .iterable import Iterable, Iterator, Reversible
+from .sequence import Sequence
 from .sized import Sized
 
 __all__ = [
+    "Collection",
     "Container",
     "Hashable",
     "Iterable",
     "Iterator",
     "Reversible",
+    "Sequence",
     "Sized",
 ]
